# 1.0 Automated Tests {#HLT005 }

## 1.1 HLT001 {#HLT001 }

Tutorial Section 1.0:

> `doorstop/cli/tests/test_tutorial.py` (line 59)

*Parent links:* [TUT001](TUT.html#TUT001), [TUT002](TUT.html#TUT002), [TUT004](TUT.html#TUT004), [TUT008](TUT.html#TUT008), [TUT017](TUT.html#TUT017), [TUT019](TUT.html#TUT019)

## 1.2 HLT002 {#HLT002 }

Tutorial Section 2.0:

> `doorstop/cli/tests/test_tutorial.py` (line 98)

*Parent links:* [TUT009](TUT.html#TUT009), [TUT010](TUT.html#TUT010)

## 1.3 HLT003 {#HLT003 }

Tutorial Section 3.0:

> `doorstop/cli/tests/test_tutorial.py` (line 121)

*Parent links:* [TUT012](TUT.html#TUT012), [TUT013](TUT.html#TUT013), [TUT016](TUT.html#TUT016)

## 1.4 HLT004 {#HLT004 }

Tutorial Section 4.0:

> `doorstop/cli/tests/test_tutorial.py` (line 143)

*Parent links:* [TUT015](TUT.html#TUT015)

